@@ -1,4 +1,5 @@
-__version__ = 'v0.3.75'
+__package_name__ = 'lightning-grid'
+__version__ = '0.8.8'
 __logo__ = """
 
 
